@@ -34,13 +34,13 @@ sub setHeader {
 	if(!defined($key)) {
 		die __PACKAGE__."#setHeader: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($key)) {
-		die __PACKAGE__."#setHeader: arg[1] is a Ref. [$key] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#setHeader: arg[1] is a reference. [$key] (第1引数がリファレンスです)\n";
 	}
 
 	if(!defined($value)) {
 		die __PACKAGE__."#setHeader: arg[2] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($value)) {
-		die __PACKAGE__."#setHeader: arg[2] is a Ref. [$value] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#setHeader: arg[2] is a reference. [$value] (第1引数がリファレンスです)\n";
 	}
 
 	$this->{replacement}{$key} = $value;
@@ -55,13 +55,13 @@ sub addHeader {
 	if(!defined($key)) {
 		die __PACKAGE__."#addHeader: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($key)) {
-		die __PACKAGE__."#addHeader: arg[1] is a Ref. [$key] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#addHeader: arg[1] is a reference. [$key] (第1引数がリファレンスです)\n";
 	}
 
 	if(!defined($value)) {
 		die __PACKAGE__."#addHeader: arg[2] is not defined. (第2引数が指定されていません)\n";
 	} elsif(ref($value)) {
-		die __PACKAGE__."#addHeader: arg[2] is a Ref. [$value] (第2引数がリファレンスです)\n";
+		die __PACKAGE__."#addHeader: arg[2] is a reference. [$value] (第2引数がリファレンスです)\n";
 	}
 
 	my $old = $this->{addition}{$key};
@@ -80,7 +80,7 @@ sub print {
 	my $data = shift;
 
 	if(ref($data)) {
-		die __PACKAGE__."#print: arg[1] is a Ref. [$data] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#print: arg[1] is a reference. [$data] (第1引数がリファレンスです)\n";
 	}
 
 	my $output = $this->_flush_header;
@@ -224,7 +224,7 @@ sub _check_options {
 				}
 			} elsif($_ eq 'scalar') {
 				if(defined($val) && ref($val)) {
-					die "TL#setContentFilter: ".ref($this).": option [$key] has to be not a Ref. [$val] (${key}オプションがリファレンスです)\n";
+					die "TL#setContentFilter: ".ref($this).": option [$key] has to be not a reference. [$val] (${key}オプションがリファレンスです)\n";
 				}
 			} elsif($_ eq 'array') {
 				if(defined($val) && ref($val) ne 'ARRAY') {
